==> rattail-tempmon-0.1.10.tar.gz: rattail-tempmon-0.1.10/rattail_tempmon/db/alembic/env.py <==
# -*- coding: utf-8 -*-
"""
Alembic Environment Script
"""

from __future__ import unicode_literals, absolute_import

from alembic import context

from rattail.config import make_config
from rattail_tempmon.db import model as tempmon


# this is the Alembic Config object, which provides
# access to the values within the .ini file in use
alembic_config = context.config

# Use same config file for Rattail, as we are for Alembic.
rattail_config = make_config(alembic_config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support
target_metadata = tempmon.Base.metadata


def run_migrations_offline():
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    engine = rattail_config.tempmon_engine
    context.configure(
        url=engine.url,
        target_metadata=target_metadata)

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online():
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    engine = rattail_config.tempmon_engine
    connection = engine.connect()
    context.configure(
        connection=connection,
        target_metadata=target_metadata)

    try:
        with context.begin_transaction():
            context.run_migrations()
    finally:
        connection.close()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()

==> rattail-tempmon-0.2.6.tar.gz: rattail-tempmon-0.2.6/rattail_tempmon/db/alembic/env.py <==
# -*- coding: utf-8 -*-
"""
Alembic Environment Script
"""

from __future__ import unicode_literals, absolute_import

from alembic import context
from sqlalchemy import orm

from rattail.config import make_config
from rattail.db.config import configure_versioning


# this is the Alembic Config object, which provides
# access to the values within the .ini file in use
alembic_config = context.config

# Use same config file for Rattail, as we are for Alembic.
rattail_config = make_config(alembic_config.config_file_name, usedb=False)

# configure Continuum...this is trickier than I'd like
configure_versioning(rattail_config)
from rattail_tempmon.db import model as tempmon
orm.configure_mappers()

# add your model's MetaData object here
# for 'autogenerate' support
target_metadata = tempmon.Base.metadata


def run_migrations_offline():
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    engine = rattail_config.tempmon_engine
    context.configure(
        url=engine.url,
        target_metadata=target_metadata)

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online():
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.

    """
    engine = rattail_config.tempmon_engine
    connection = engine.connect()
    context.configure(
        connection=connection,
        target_metadata=target_metadata)

    try:
        with context.begin_transaction():
            context.run_migrations()
    finally:
        connection.close()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
